diff -urN linux/fs/buffer.c linux-2.3.3-work/fs/buffer.c
--- linux/fs/buffer.c	Wed May 19 20:40:12 1999
+++ linux-2.3.3-work/fs/buffer.c	Wed May 19 22:45:51 1999
@@ -60,7 +60,7 @@
  */
 static unsigned long bh_hash_mask = 0;
 
-static int grow_buffers(int size);
+static int grow_buffers(int);
 
 static struct buffer_head ** hash_table;
 static struct buffer_head * lru_list[NR_LIST] = {NULL, };
@@ -90,7 +90,7 @@
 /* The dummy values in this structure are left in there for compatibility
  * with old programs that play with the /proc entries.
  */
-union bdflush_param{
+union bdflush_param {
 	struct {
 		int nfract;  /* Percentage of buffer cache dirty to 
 				activate bdflush */
diff -urN linux/fs/minix/bitmap.c linux-2.3.3-work/fs/minix/bitmap.c
--- linux/fs/minix/bitmap.c	Tue Oct 20 22:08:14 1998
+++ linux-2.3.3-work/fs/minix/bitmap.c	Wed May 19 22:02:40 1999
@@ -140,7 +140,7 @@
 	if (!ino || ino > inode->i_sb->u.minix_sb.s_ninodes) {
 		printk("Bad inode number on dev %s: %d is out of range\n",
 		       kdevname(inode->i_dev), ino);
-		return 0;
+		return NULL;
 	}
 	block = (2 + inode->i_sb->u.minix_sb.s_imap_blocks +
 		 inode->i_sb->u.minix_sb.s_zmap_blocks +
@@ -148,7 +148,7 @@
 	bh = bread(inode->i_dev, block, BLOCK_SIZE);
 	if (!bh) {
 		printk("unable to read i-node block\n");
-		return 0;
+		return NULL;
 	}
 	raw_inode = ((struct minix_inode *)bh->b_data +
 		     (ino - 1) % MINIX_INODES_PER_BLOCK);
@@ -168,7 +168,7 @@
 	if (!ino || ino > inode->i_sb->u.minix_sb.s_ninodes) {
 		printk("Bad inode number on dev %s: %d is out of range\n",
 		       kdevname(inode->i_dev), ino);
-		return 0;
+		return NULL;
 	}
 	block = (2 + inode->i_sb->u.minix_sb.s_imap_blocks +
 		 inode->i_sb->u.minix_sb.s_zmap_blocks +
@@ -176,7 +176,7 @@
 	bh = bread(inode->i_dev, block, BLOCK_SIZE);
 	if (!bh) {
 		printk("unable to read i-node block\n");
-		return 0;
+		return NULL;
 	}
 	raw_inode = ((struct minix2_inode *) bh->b_data +
 		     (ino - 1) % MINIX2_INODES_PER_BLOCK);
diff -urN linux/fs/minix/namei.c linux-2.3.3-work/fs/minix/namei.c
--- linux/fs/minix/namei.c	Wed May 19 20:40:16 1999
+++ linux-2.3.3-work/fs/minix/namei.c	Wed May 19 22:00:43 1999
@@ -184,12 +184,7 @@
 			dir->i_size = block*bh->b_size + offset;
 			mark_inode_dirty(dir);
 		}
-		if (de->inode) {
-			if (namecompare(namelen, info->s_namelen, name, de->name)) {
-				brelse(bh);
-				return -EEXIST;
-			}
-		} else {
+		if (!de->inode) {
 			dir->i_mtime = dir->i_ctime = CURRENT_TIME;
 			mark_inode_dirty(dir);
 			for (i = 0; i < info->s_namelen ; i++)
diff -urN linux/fs/nfsd/export.c linux-2.3.3-work/fs/nfsd/export.c
--- linux/fs/nfsd/export.c	Wed May 19 20:40:05 1999
+++ linux-2.3.3-work/fs/nfsd/export.c	Wed May 19 22:22:24 1999
@@ -168,9 +168,8 @@
 					}
 				} while (NULL != (exp = exp->ex_next));
 		} while (nfsd_parentdev(&xdev));
-		if (xdentry == xdentry->d_parent) {
+		if (IS_ROOT(xdentry))
 			break;
-		}
 	} while ((xdentry = xdentry->d_parent));
 	exp = NULL;
 out:
@@ -204,7 +203,7 @@
 #endif
 						goto out;
 					}
-					if (ndentry == ndentry->d_parent)
+					if (IS_ROOT(ndentry))
 						break;
 				}
 		} while (NULL != (exp = exp->ex_next));
diff -urN linux/fs/nfsd/nfsfh.c linux-2.3.3-work/fs/nfsd/nfsfh.c
--- linux/fs/nfsd/nfsfh.c	Wed May 19 20:40:13 1999
+++ linux-2.3.3-work/fs/nfsd/nfsfh.c	Wed May 19 22:24:01 1999
@@ -531,7 +531,7 @@
 	 * Add the parent to the dir cache before releasing the dentry,
 	 * and check whether to save a copy of the dentry's path.
 	 */
-	if (dentry != dentry->d_parent) {
+	if (!IS_ROOT(dentry)) {
 		struct dentry *parent = dget(dentry->d_parent);
 		if (add_to_fhcache(parent, NFSD_DIR_CACHE))
 			nfsd_nr_verified++;
@@ -1140,7 +1140,7 @@
 				error = nfserr_stale;
 dprintk("fh_verify: no root_squashed access.\n");
 			}
-		} while ((tdentry != tdentry->d_parent));
+		} while (!IS_ROOT(tdentry));
 		if (exp->ex_dentry != tdentry) {
 			error = nfserr_stale;
 			printk("nfsd Security: %s/%s bad export.\n",
diff -urN linux/fs/proc/link.c linux-2.3.3-work/fs/proc/link.c
--- linux/fs/proc/link.c	Tue Apr 13 00:18:26 1999
+++ linux-2.3.3-work/fs/proc/link.c	Wed May 19 22:18:04 1999
@@ -146,7 +146,7 @@
 	/* Check for special dentries.. */
 	pattern = NULL;
 	inode = dentry->d_inode;
-	if (inode && dentry->d_parent == dentry) {
+	if (inode && IS_ROOT(dentry)) {
 		if (S_ISSOCK(inode->i_mode))
 			pattern = "socket:[%lu]";
 		if (S_ISFIFO(inode->i_mode))
diff -urN linux/fs/smbfs/dir.c linux-2.3.3-work/fs/smbfs/dir.c
--- linux/fs/smbfs/dir.c	Sun May  9 01:56:37 1999
+++ linux-2.3.3-work/fs/smbfs/dir.c	Wed May 19 22:20:36 1999
@@ -318,7 +318,7 @@
 	for (;;)
 	{
 		dentry->d_time = jiffies;
-		if (dentry == dentry->d_parent)
+		if (IS_ROOT(dentry))
 			break;
 		dentry = dentry->d_parent;
 	}
diff -urN linux/fs/super.c linux-2.3.3-work/fs/super.c
--- linux/fs/super.c	Wed May 19 20:40:16 1999
+++ linux-2.3.3-work/fs/super.c	Wed May 19 22:48:53 1999
@@ -169,20 +169,20 @@
 
 int register_filesystem(struct file_system_type * fs)
 {
-        struct file_system_type ** tmp;
+	struct file_system_type ** tmp;
 
-        if (!fs)
-                return -EINVAL;
-        if (fs->next)
-                return -EBUSY;
-        tmp = &file_systems;
-        while (*tmp) {
-                if (strcmp((*tmp)->name, fs->name) == 0)
-                        return -EBUSY;
-                tmp = &(*tmp)->next;
-        }
-        *tmp = fs;
-        return 0;
+	if (!fs)
+		return -EINVAL;
+	if (fs->next)
+		return -EBUSY;
+	tmp = &file_systems;
+	while (*tmp) {
+		if (strcmp((*tmp)->name, fs->name) == 0)
+			return -EBUSY;
+		tmp = &(*tmp)->next;
+	}
+	*tmp = fs;
+	return 0;
 }
 
 #ifdef CONFIG_MODULES
diff -urN linux/fs/umsdos/check.c linux-2.3.3-work/fs/umsdos/check.c
--- linux/fs/umsdos/check.c	Fri Dec 18 15:09:36 1998
+++ linux-2.3.3-work/fs/umsdos/check.c	Wed May 19 22:18:32 1999
@@ -212,7 +212,7 @@
 	
 	while (dentry && count < 10) {
 		check_dent_int (dentry, count++);
-		if (dentry == dentry->d_parent) {
+		if (IS_ROOT(dentry)) {
 			printk (KERN_DEBUG "*** end checking dentry (root reached ok)\n");
 			break;
 		}
diff -urN linux/include/linux/dcache.h linux-2.3.3-work/include/linux/dcache.h
--- linux/include/linux/dcache.h	Sun May  9 01:56:37 1999
+++ linux-2.3.3-work/include/linux/dcache.h	Wed May 19 20:53:39 1999
@@ -12,8 +12,6 @@
  * with heavy changes by Linus Torvalds
  */
 
-#define D_MAXLEN 1024
-
 #define IS_ROOT(x) ((x) == (x)->d_parent)
 
 /*
@@ -30,7 +28,8 @@
 #define init_name_hash()		0
 
 /* partial hash update function. Assume roughly 4 bits per character */
-static __inline__ unsigned long partial_name_hash(unsigned long c, unsigned long prevhash)
+static __inline__ unsigned long 
+partial_name_hash(unsigned long c, unsigned long prevhash)
 {
 	prevhash = (prevhash << 4) | (prevhash >> (8*sizeof(unsigned long)-4));
 	return prevhash ^ c;
@@ -45,7 +44,8 @@
 }
 
 /* Compute the hash for a name string. */
-static __inline__ unsigned int full_name_hash(const unsigned char * name, unsigned int len)
+static __inline__ unsigned int 
+full_name_hash(const unsigned char * name, unsigned int len)
 {
 	unsigned long hash = init_name_hash();
 	while (len--)
@@ -114,13 +114,15 @@
  * to invalidate a dentry for some reason (NFS
  * timeouts or autofs deletes).
  */
-static __inline__ void d_drop(struct dentry * dentry)
+static __inline__ void 
+d_drop(struct dentry * dentry)
 {
 	list_del(&dentry->d_hash);
 	INIT_LIST_HEAD(&dentry->d_hash);
 }
 
-static __inline__ int dname_external(struct dentry *d)
+static __inline__ int 
+dname_external(struct dentry *d)
 {
 	return d->d_name.name != d->d_iname; 
 }
@@ -132,7 +134,7 @@
 extern void d_delete(struct dentry *);
 
 /* allocate/de-allocate */
-extern struct dentry * d_alloc(struct dentry * parent, const struct qstr *name);
+extern struct dentry * d_alloc(struct dentry *, const struct qstr *);
 extern void prune_dcache(int);
 extern void shrink_dcache_sb(struct super_block *);
 extern void shrink_dcache_parent(struct dentry *);
@@ -147,7 +149,7 @@
 extern void free_inode_memory(int);	/* defined in fs/inode.c */
 
 /* only used at mount-time */
-extern struct dentry * d_alloc_root(struct inode * root_inode, struct dentry * old_root);
+extern struct dentry * d_alloc_root(struct inode *, struct dentry *);
 
 /* test whether root is busy without destroying dcache */
 extern int is_root_busy(struct dentry *);
@@ -155,7 +157,7 @@
 /*
  * This adds the entry to the hash queues.
  */
-extern void d_rehash(struct dentry * entry);
+extern void d_rehash(struct dentry *);
 /*
  * This adds the entry to the hash queues and initializes "d_inode".
  * The entry was actually filled in earlier during "d_alloc()"
@@ -167,19 +169,18 @@
 }
 
 /* used for rename() and baskets */
-extern void d_move(struct dentry * entry, struct dentry * newdentry);
+extern void d_move(struct dentry *, struct dentry *);
 
 /* appendix may either be NULL or be used for transname suffixes */
-extern struct dentry * d_lookup(struct dentry * dir, struct qstr * name);
+extern struct dentry * d_lookup(struct dentry *, struct qstr *);
 
 /* validate "insecure" dentry pointer */
-extern int d_validate(struct dentry *dentry, struct dentry *dparent,
-		      unsigned int hash, unsigned int len);
+extern int d_validate(struct dentry *, struct dentry *, unsigned int, unsigned int);
 
 /* write full pathname into buffer and return start of pathname */
-extern char * d_path(struct dentry * entry, char * buf, int buflen);
+extern char * d_path(struct dentry *, char *, int);
 
-/* Allocation counts.. */
+/* Allocation counts */
 static __inline__ struct dentry * dget(struct dentry *dentry)
 {
 	if (dentry)
diff -urN linux/include/linux/file.h linux-2.3.3-work/include/linux/file.h
--- linux/include/linux/file.h	Sun Jan 10 03:16:44 1999
+++ linux-2.3.3-work/include/linux/file.h	Wed May 19 20:52:46 1999
@@ -11,7 +11,7 @@
  * Check whether the specified task has the fd open. Since the task
  * may not have a files_struct, we must test for p->files != NULL.
  */
-extern inline struct file * fcheck_task(struct task_struct *p, unsigned int fd)
+extern inline struct file * fcheck_task(struct task_struct * p, unsigned int fd)
 {
 	struct file * file = NULL;
 
@@ -44,7 +44,7 @@
 /*
  * Install a file pointer in the fd array.
  */
-extern inline void fd_install(unsigned int fd, struct file *file)
+extern inline void fd_install(unsigned int fd, struct file * file)
 {
 	current->files->fd[fd] = file;
 }
@@ -65,7 +65,7 @@
  * I suspect there are many other similar "optimizations" across the
  * kernel...
  */
-extern void fput(struct file *file); 
-extern void put_filp(struct file *file);
+extern void fput(struct file *); 
+extern void put_filp(struct file *);
 
-#endif
+#endif /* __LINUX_FILE_H */
diff -urN linux/include/linux/fs.h linux-2.3.3-work/include/linux/fs.h
--- linux/include/linux/fs.h	Wed May 19 20:40:17 1999
+++ linux-2.3.3-work/include/linux/fs.h	Wed May 19 22:38:23 1999
@@ -103,7 +103,8 @@
 /*
  * Flags that can be altered by MS_REMOUNT
  */
-#define MS_RMT_MASK (MS_RDONLY|MS_NOSUID|MS_NODEV|MS_NOEXEC|MS_SYNCHRONOUS|MS_MANDLOCK|MS_NOATIME|MS_NODIRATIME)
+#define MS_RMT_MASK	(MS_RDONLY|MS_NOSUID|MS_NODEV|MS_NOEXEC|\
+			MS_SYNCHRONOUS|MS_MANDLOCK|MS_NOATIME|MS_NODIRATIME)
 
 /*
  * Magic mount flag number. Has to be or-ed to the flag values.
@@ -112,7 +113,7 @@
 #define MS_MGC_MSK 0xffff0000	/* magic flag number mask */
 
 /*
- * Note that read-only etc flags are inode-specific: setting some file-system
+ * Note that nosuid etc flags are inode-specific: setting some file-system
  * flags just means all the inodes inherit those flags by default. It might be
  * possible to override it selectively if you really wanted to with some
  * ioctl() that is not currently implemented.
@@ -173,7 +174,7 @@
 #include <asm/byteorder.h>
 #include <asm/bitops.h>
 
-extern void update_atime (struct inode *inode);
+extern void update_atime (struct inode *);
 #define UPDATE_ATIME(inode) update_atime (inode)
 
 extern void buffer_init(unsigned long);
@@ -232,9 +233,8 @@
 	void *b_dev_id;
 };
 
-typedef void (bh_end_io_t)(struct buffer_head *bh, int uptodate);
-void init_buffer(struct buffer_head *bh, kdev_t dev, int block,
-		 bh_end_io_t *handler, void *dev_id);
+typedef void (bh_end_io_t)(struct buffer_head * bh, int uptodate);
+void init_buffer(struct buffer_head *, kdev_t, int, bh_end_io_t *, void *);
 
 static inline int buffer_uptodate(struct buffer_head * bh)
 {
@@ -480,11 +480,11 @@
 
 #include <linux/fcntl.h>
 
-extern int fcntl_getlk(unsigned int fd, struct flock *l);
-extern int fcntl_setlk(unsigned int fd, unsigned int cmd, struct flock *l);
+extern int fcntl_getlk(unsigned int, struct flock *);
+extern int fcntl_setlk(unsigned int, unsigned int, struct flock *);
 
 /* fs/locks.c */
-extern void locks_remove_posix(struct file *, fl_owner_t id);
+extern void locks_remove_posix(struct file *, fl_owner_t);
 extern void locks_remove_flock(struct file *);
 extern struct file_lock *posix_test_lock(struct file *, struct file_lock *);
 extern int posix_lock_file(struct file *, struct file_lock *, unsigned int);
@@ -667,10 +667,8 @@
 #define FLOCK_VERIFY_READ  1
 #define FLOCK_VERIFY_WRITE 2
 
-extern int locks_mandatory_locked(struct inode *inode);
-extern int locks_mandatory_area(int read_write, struct inode *inode,
-				struct file *filp, loff_t offset,
-				size_t count);
+extern int locks_mandatory_locked(struct inode *);
+extern int locks_mandatory_area(int, struct inode *, struct file *, loff_t, size_t);
 
 extern inline int locks_verify_locked(struct inode *inode)
 {
@@ -709,35 +707,35 @@
 extern struct file *filp_open(const char *, int, int);
 extern int filp_close(struct file *, fl_owner_t id);
 
-extern char * getname(const char * filename);
+extern char * getname(const char *);
 #define __getname()	((char *) __get_free_page(GFP_KERNEL))
 #define putname(name)	free_page((unsigned long)(name))
 
-extern void kill_fasync(struct fasync_struct *fa, int sig);
+extern void kill_fasync(struct fasync_struct *, int);
 extern int register_blkdev(unsigned int, const char *, struct file_operations *);
-extern int unregister_blkdev(unsigned int major, const char * name);
-extern int blkdev_open(struct inode * inode, struct file * filp);
-extern int blkdev_release (struct inode * inode);
+extern int unregister_blkdev(unsigned int, const char *);
+extern int blkdev_open(struct inode *, struct file *);
+extern int blkdev_release (struct inode *);
 extern struct file_operations def_blk_fops;
 extern struct inode_operations blkdev_inode_operations;
 
 /* fs/devices.c */
 extern int register_chrdev(unsigned int, const char *, struct file_operations *);
-extern int unregister_chrdev(unsigned int major, const char * name);
-extern int chrdev_open(struct inode * inode, struct file * filp);
+extern int unregister_chrdev(unsigned int, const char *);
+extern int chrdev_open(struct inode *, struct file *);
 extern struct file_operations def_chr_fops;
 extern struct inode_operations chrdev_inode_operations;
-extern char * bdevname(kdev_t dev);
-extern char * cdevname(kdev_t dev);
-extern char * kdevname(kdev_t dev);
+extern char * bdevname(kdev_t);
+extern char * cdevname(kdev_t);
+extern char * kdevname(kdev_t);
 extern void init_special_inode(struct inode *, umode_t, int);
 
-extern void init_fifo(struct inode * inode);
+extern void init_fifo(struct inode *);
 extern struct inode_operations fifo_inode_operations;
 
 /* Invalid inode operations -- fs/bad_inode.c */
-extern void make_bad_inode(struct inode * inode);
-extern int is_bad_inode(struct inode * inode);
+extern void make_bad_inode(struct inode *);
+extern int is_bad_inode(struct inode *);
 
 extern struct file_operations connecting_fifo_fops;
 extern struct file_operations read_fifo_fops;
@@ -747,15 +745,15 @@
 extern struct file_operations write_pipe_fops;
 extern struct file_operations rdwr_pipe_fops;
 
-extern struct file_system_type *get_fs_type(const char *name);
+extern struct file_system_type *get_fs_type(const char *);
 
 extern int fs_may_remount_ro(struct super_block *);
-extern int fs_may_mount(kdev_t dev);
+extern int fs_may_mount(kdev_t);
 
-extern struct file *inuse_filps;
+extern struct file * inuse_filps;
 
-extern void refile_buffer(struct buffer_head * buf);
-extern void set_writetime(struct buffer_head * buf, int flag);
+extern void refile_buffer(struct buffer_head *);
+extern void set_writetime(struct buffer_head *, int);
 extern int try_to_free_buffers(struct page *);
 
 extern int nr_buffers;
@@ -767,7 +765,7 @@
 #define BUF_DIRTY	2	/* Dirty buffers, not yet scheduled for write */
 #define NR_LIST		3
 
-void mark_buffer_uptodate(struct buffer_head * bh, int on);
+void mark_buffer_uptodate(struct buffer_head *, int);
 
 extern inline void mark_buffer_clean(struct buffer_head * bh)
 {
@@ -786,23 +784,23 @@
 	}
 }
 
-extern int check_disk_change(kdev_t dev);
-extern int invalidate_inodes(struct super_block * sb);
+extern int check_disk_change(kdev_t);
+extern int invalidate_inodes(struct super_block *);
 extern void invalidate_inode_pages(struct inode *);
-extern void invalidate_buffers(kdev_t dev);
-extern int floppy_is_wp(int minor);
-extern void sync_inodes(kdev_t dev);
-extern void write_inode_now(struct inode *inode);
-extern void sync_dev(kdev_t dev);
-extern int fsync_dev(kdev_t dev);
-extern void sync_supers(kdev_t dev);
-extern int bmap(struct inode * inode,int block);
+extern void invalidate_buffers(kdev_t);
+extern int floppy_is_wp(int);
+extern void sync_inodes(kdev_t);
+extern void write_inode_now(struct inode *);
+extern void sync_dev(kdev_t);
+extern int fsync_dev(kdev_t);
+extern void sync_supers(kdev_t);
+extern int bmap(struct inode *, int);
 extern int notify_change(struct dentry *, struct iattr *);
-extern int permission(struct inode * inode,int mask);
-extern int get_write_access(struct inode *inode);
-extern void put_write_access(struct inode *inode);
-extern struct dentry * open_namei(const char * pathname, int flag, int mode);
-extern struct dentry * do_mknod(const char * filename, int mode, dev_t dev);
+extern int permission(struct inode *, int);
+extern int get_write_access(struct inode *);
+extern void put_write_access(struct inode *);
+extern struct dentry * open_namei(const char *, int, int);
+extern struct dentry * do_mknod(const char *, int, dev_t);
 extern int do_pipe(int *);
 
 /* fs/dcache.c -- generic fs support functions */
@@ -840,7 +838,7 @@
 #define lnamei(pathname)	__namei(pathname, 0)
 
 extern void iput(struct inode *);
-extern struct inode * igrab(struct inode *inode);
+extern struct inode * igrab(struct inode *);
 extern ino_t iunique(struct super_block *, ino_t);
 extern struct inode * iget(struct super_block *, unsigned long);
 extern void clear_inode(struct inode *);
@@ -851,7 +849,7 @@
 extern struct file * get_empty_filp(void);
 extern struct buffer_head * get_hash_table(kdev_t, int, int);
 extern struct buffer_head * getblk(kdev_t, int, int);
-extern struct buffer_head * find_buffer(kdev_t dev, int block, int size);
+extern struct buffer_head * find_buffer(kdev_t, int, int);
 extern void ll_rw_block(int, int, struct buffer_head * bh[]);
 extern int is_read_only(kdev_t);
 extern void __brelse(struct buffer_head *);
@@ -860,29 +858,29 @@
 	if (buf)
 		__brelse(buf);
 }
-extern void __bforget(struct buffer_head *buf);
+
+extern void __bforget(struct buffer_head *);
 extern inline void bforget(struct buffer_head *buf)
 {
 	if (buf)
 		__bforget(buf);
 }
-extern void set_blocksize(kdev_t dev, int size);
-extern unsigned int get_hardblocksize(kdev_t dev);
-extern struct buffer_head * bread(kdev_t dev, int block, int size);
-extern struct buffer_head * breada(kdev_t dev,int block, int size, 
-				   unsigned int pos, unsigned int filesize);
+extern void set_blocksize(kdev_t, int);
+extern unsigned int get_hardblocksize(kdev_t);
+extern struct buffer_head * bread(kdev_t, int, int);
+extern struct buffer_head * breada(kdev_t, int, int, unsigned int, unsigned int);
 
 extern int brw_page(int, struct page *, kdev_t, int [], int, int);
 
 extern int generic_readpage(struct file *, struct page *);
 extern int generic_file_mmap(struct file *, struct vm_area_struct *);
 extern ssize_t generic_file_read(struct file *, char *, size_t, loff_t *);
-extern ssize_t generic_file_write(struct file *, const char*, size_t, loff_t*);
+extern ssize_t generic_file_write(struct file *, const char *, size_t, loff_t *);
 
-extern struct super_block *get_super(kdev_t dev);
-extern void put_super(kdev_t dev);
-unsigned long generate_cluster(kdev_t dev, int b[], int size);
-unsigned long generate_cluster_swab32(kdev_t dev, int b[], int size);
+extern struct super_block *get_super(kdev_t);
+extern void put_super(kdev_t);
+unsigned long generate_cluster(kdev_t, int b[], int);
+unsigned long generate_cluster_swab32(kdev_t, int b[], int);
 extern kdev_t ROOT_DEV;
 
 extern void show_buffers(void);
@@ -890,7 +888,7 @@
 
 #ifdef CONFIG_BLK_DEV_INITRD
 extern kdev_t real_root_dev;
-extern int change_root(kdev_t new_root_dev,const char *put_old);
+extern int change_root(kdev_t, const char *);
 #endif
 
 extern ssize_t char_read(struct file *, char *, size_t, loff_t *);
@@ -900,8 +898,8 @@
 extern ssize_t char_write(struct file *, const char *, size_t, loff_t *);
 extern ssize_t block_write(struct file *, const char *, size_t, loff_t *);
 
-extern int block_fsync(struct file *, struct dentry *dir);
-extern int file_fsync(struct file *, struct dentry *dir);
+extern int block_fsync(struct file *, struct dentry *);
+extern int file_fsync(struct file *, struct dentry *);
 
 extern int inode_change_ok(struct inode *, struct iattr *);
 extern void inode_setattr(struct inode *, struct iattr *);
diff -urN linux/include/linux/sched.h linux-2.3.3-work/include/linux/sched.h
--- linux/include/linux/sched.h	Wed May 19 20:40:08 1999
+++ linux-2.3.3-work/include/linux/sched.h	Wed May 19 22:45:07 1999
@@ -162,9 +162,9 @@
 #define AVL_MIN_MAP_COUNT	32
 
 struct mm_struct {
-	struct vm_area_struct *mmap;		/* list of VMAs */
-	struct vm_area_struct *mmap_avl;	/* tree of VMAs */
-	struct vm_area_struct *mmap_cache;	/* last find_vma result */
+	struct vm_area_struct * mmap;		/* list of VMAs */
+	struct vm_area_struct * mmap_avl;	/* tree of VMAs */
+	struct vm_area_struct * mmap_cache;	/* last find_vma result */
 	pgd_t * pgd;
 	atomic_t count;
 	int map_count;				/* number of VMAs */
@@ -448,8 +448,8 @@
 }
 
 /* per-UID process charging. */
-extern int alloc_uid(struct task_struct *p);
-void free_uid(struct task_struct *p);
+extern int alloc_uid(struct task_struct *);
+void free_uid(struct task_struct *);
 
 #include <asm/current.h>
 
@@ -481,22 +481,21 @@
 
 extern void flush_signals(struct task_struct *);
 extern void flush_signal_handlers(struct task_struct *);
-extern int dequeue_signal(sigset_t *block, siginfo_t *);
-extern int send_sig_info(int, struct siginfo *info, struct task_struct *);
-extern int force_sig_info(int, struct siginfo *info, struct task_struct *);
-extern int kill_pg_info(int, struct siginfo *info, pid_t);
-extern int kill_sl_info(int, struct siginfo *info, pid_t);
-extern int kill_proc_info(int, struct siginfo *info, pid_t);
-extern int kill_something_info(int, struct siginfo *info, int);
-extern void notify_parent(struct task_struct * tsk, int);
-extern void force_sig(int sig, struct task_struct * p);
-extern int send_sig(int sig, struct task_struct * p, int priv);
+extern int dequeue_signal(sigset_t *, siginfo_t *);
+extern int send_sig_info(int, struct siginfo *, struct task_struct *);
+extern int force_sig_info(int, struct siginfo *, struct task_struct *);
+extern int kill_pg_info(int, struct siginfo *, pid_t);
+extern int kill_sl_info(int, struct siginfo *, pid_t);
+extern int kill_proc_info(int, struct siginfo *, pid_t);
+extern int kill_something_info(int, struct siginfo *, int);
+extern void notify_parent(struct task_struct *, int);
+extern void force_sig(int, struct task_struct *);
+extern int send_sig(int, struct task_struct *, int);
 extern int kill_pg(pid_t, int, int);
 extern int kill_sl(pid_t, int, int);
 extern int kill_proc(pid_t, int, int);
-extern int do_sigaction(int sig, const struct k_sigaction *act,
-			struct k_sigaction *oact);
-extern int do_sigaltstack(const stack_t *ss, stack_t *oss, unsigned long sp);
+extern int do_sigaction(int, const struct k_sigaction *, struct k_sigaction *);
+extern int do_sigaltstack(const stack_t *, stack_t *, unsigned long);
 
 extern inline int signal_pending(struct task_struct *p)
 {
@@ -548,12 +547,10 @@
 		: on_sig_stack(sp) ? SS_ONSTACK : 0);
 }
 
-extern int request_irq(unsigned int irq,
+extern int request_irq(unsigned int,
 		       void (*handler)(int, void *, struct pt_regs *),
-		       unsigned long flags, 
-		       const char *device,
-		       void *dev_id);
-extern void free_irq(unsigned int irq, void *dev_id);
+		       unsigned long, const char *, void *);
+extern void free_irq(unsigned int, void *);
 
 /*
  * This has now become a routine instead of a macro, it sets a flag if
@@ -619,7 +616,8 @@
 /* Remove the current tasks stale references to the old mm_struct */
 extern void mm_release(void);
 
-extern int  copy_thread(int, unsigned long, unsigned long, struct task_struct *, struct pt_regs *);
+extern int  copy_thread(int, unsigned long, unsigned long, 
+			struct task_struct *, struct pt_regs *);
 extern void flush_thread(void);
 extern void exit_thread(void);
 
@@ -631,7 +629,7 @@
 extern int do_execve(char *, char **, char **, struct pt_regs *);
 extern int do_fork(unsigned long, unsigned long, struct pt_regs *);
 
-extern inline void add_wait_queue(wait_queue_head_t *q, wait_queue_t * wait)
+extern inline void add_wait_queue(wait_queue_head_t * q, wait_queue_t * wait)
 {
 	unsigned long flags;
 
@@ -640,7 +638,7 @@
 	wq_write_unlock_irqrestore(&q->lock, flags);
 }
 
-extern inline void add_wait_queue_exclusive(wait_queue_head_t *q,
+extern inline void add_wait_queue_exclusive(wait_queue_head_t * q,
 							wait_queue_t * wait)
 {
 	unsigned long flags;
@@ -650,7 +648,7 @@
 	wq_write_unlock_irqrestore(&q->lock, flags);
 }
 
-extern inline void remove_wait_queue(wait_queue_head_t *q, wait_queue_t * wait)
+extern inline void remove_wait_queue(wait_queue_head_t * q, wait_queue_t * wait)
 {
 	unsigned long flags;
 
